pub struct ScrollObjects {
pub scroll_defs: HashMap<ObjId, Decimal>,
pub scrolling_factor_changes: BTreeMap<ObjTime, ScrollingFactorObj>,
}Expand description
This aggregate manages definition and events of scroll speed change.
Fields
scroll_defs: HashMap<ObjId, Decimal>Scroll speed change definitions, indexed by ObjId. #SCROLL[01-ZZ]
scrolling_factor_changes: BTreeMap<ObjTime, ScrollingFactorObj>The scrolling factors corresponding to the id of the scroll speed change object.
Implementations
Sourceimpl ScrollObjects
impl ScrollObjects
Sourcepub fn push_scrolling_factor_change(
&mut self,
scrolling_factor_change: ScrollingFactorObj,
prompt_handler: &impl Prompter,
) -> Result<(), ParseWarning>
pub fn push_scrolling_factor_change( &mut self, scrolling_factor_change: ScrollingFactorObj, prompt_handler: &impl Prompter, ) -> Result<(), ParseWarning>
Adds a new scrolling factor change object to the notes.