pub struct Sprites {
pub back_bmp: Option<PathBuf>,
pub stage_file: Option<PathBuf>,
pub banner: Option<PathBuf>,
pub extchr_events: Vec<ExtChrEvent>,
pub char_file: Option<PathBuf>,
}Expand description
This aggregate manages external paths to image assets.
Fields
back_bmp: Option<PathBuf>The path of background image, which is shown while playing the score. This image is displayed behind the gameplay area.
stage_file: Option<PathBuf>The path of splash screen image, which is shown before playing the score. This image is displayed during the loading screen.
The path of banner image. This image is used in music selection screens.
extchr_events: Vec<ExtChrEvent>Extended-character events. #ExtChr
char_file: Option<PathBuf>Character file path. #CHARFILE