Module token_processor

Module token_processor 

This module provides TokenProcessor and its implementations, which reads Token and applies data to Bms.

Also it provides preset functions that returns a TokenProcessor trait object:

  • [common_preset] - Commonly used processors.
  • [minor_preset] - All of processors this crate provided.

Structs

Mapped
A processor SequentialProcessor which maps the output of the token processor TP by the function F.
SequentialProcessor
A processor SequentialProcessor which does first then second.

Traits

TokenProcessor
A processor of tokens in the BMS. An implementation takes control only one feature about definitions and placements such as WAVxx definition and its sound object.

Type Aliases

TokenProcessorResult
A type alias of Result<T, Vec<ParseWarningWithRange>.