pub struct ParseConfig<T, P, R> { /* private fields */ }Expand description
A configuration builder for parse_bms. Its methods can be chained to set parameters you want.
Implementations
Sourceimpl<T, P, R> ParseConfig<T, P, R>
impl<T, P, R> ParseConfig<T, P, R>
Sourcepub fn key_mapper<T2: KeyLayoutMapper>(self) -> ParseConfig<T2, P, R>
pub fn key_mapper<T2: KeyLayoutMapper>(self) -> ParseConfig<T2, P, R>
Sets the key mapper to the T2 one.
Sourcepub fn prompter<P2: Prompter>(self, prompter: P2) -> ParseConfig<T, P2, R>
pub fn prompter<P2: Prompter>(self, prompter: P2) -> ParseConfig<T, P2, R>
Sets the prompter to prompter.
Sourcepub fn rng<R2: Rng>(self, rng: R2) -> ParseConfig<T, P, R2>
pub fn rng<R2: Rng>(self, rng: R2) -> ParseConfig<T, P, R2>
Sets the RNG to rng.
Sourcepub fn use_common(self) -> Self
pub fn use_common(self) -> Self
Change to use common token processors that don’t try to parse minor commands.
Sourcepub fn use_minor(self) -> Self
pub fn use_minor(self) -> Self
Change to use minor token processors that try to parse minor commands. This is the default option.
Sourcepub fn use_pedantic(self) -> Self
pub fn use_pedantic(self) -> Self
Change to use pedantic token processors that don’t recognize common mistakes.
Sourcepub fn use_relaxed(self) -> Self
pub fn use_relaxed(self) -> Self
Change to use relaxed token processors that recognize common mistakes. This is the default option.