SimpleSource

Struct SimpleSource 

pub struct SimpleSource<'a> { /* private fields */ }
Simple source container that holds the filename and source text. Ariadne will automatically handle row/column calculations from byte offsets.

Usage Example

use bms_rs::diagnostics::SimpleSource;

// Create source container
let source_text = "#TITLE test\n#ARTIST composer\n";
let source = SimpleSource::new("test.bms", source_text);

// Get source text
assert_eq!(source.text(), source_text);

Implementations

Source

impl<'a> SimpleSource<'a>

pub const fn new(name: &'a str, text: &'a str) -> Self

Create a new source container instance.

Parameters
  • name - Name of the source file
  • text - Complete text content of the source file
pub const fn text(&self) -> &'a str

Get source text content.

Returns

Returns the complete text content of the source file

pub const fn name(&self) -> &'a str

Get source file name.

Returns

Returns the name of the source file