This module provides TokenProcessor and its implementations, which reads Token and applies data to Bms.
Also it provides preset functions that returns a TokenProcessor trait object:
- [
common_preset] - Commonly used processors. - [
minor_preset] - All of processors this crate provided.
Structs
- Mapped
- A processor
SequentialProcessorwhich maps the output of the token processorTPby the functionF. - Sequential
Processor - A processor
SequentialProcessorwhich doesfirstthensecond.
Traits
- Token
Processor - A processor of tokens in the BMS. An implementation takes control only one feature about definitions and placements such as
WAVxxdefinition and its sound object.
Type Aliases
- Token
Processor Result - A type alias of
Result<T, Vec<ParseWarningWithRange>.